package org.tinygroup.databasebuinstaller;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.List;

import org.tinygroup.appconfig.AppConfig;
import org.tinygroup.logger.LogLevel;
import org.tinygroup.logger.Logger;
import org.tinygroup.logger.LoggerFactory;
import org.tinygroup.xmlparser.node.XmlNode;

/**
 * 
 * 功能说明:数据库安装类 
 * <p> 系统版本: v1.0<br>
 * 开发人员: renhui <br>
 * 开发时间: 2013-8-15 <br>
 * 功能描述: 写明作用，调用方式，使用场景，以及特殊情况<br>
 */
public class DatabaseInstaller implements AppConfig{
	public static final String DATABASE_INSTALLER_BEAN_NAME="databaseInstaller";
	private Logger logger = LoggerFactory.getLogger(DatabaseInstaller.class);
	private String defaultLanuage = "oracle";
	private String dbLanguage = "";
	private XmlNode config ;
	private List<InstallProcessor> installProcessors=new ArrayList<InstallProcessor>();
	
	public Logger getLogger() {
		return logger;
	}

	public void setLogger(Logger logger) {
		this.logger = logger;
	}

	public String getDefaultLanuage() {
		return defaultLanuage;
	}

	public void setDefaultLanuage(String defaultLanuage) {
		this.defaultLanuage = defaultLanuage;
	}

	public String getDbLanguage() {
		return dbLanguage;
	}

	public void setDbLanguage(String dbLanguage) {
		this.dbLanguage = dbLanguage;
	}

	public XmlNode getConfig() {
		return config;
	}

	public void setConfig(XmlNode config) {
		this.config = config;
	}

	public List<InstallProcessor> getInstallProcessors() {
		return installProcessors;
	}

	public void setInstallProcessors(List<InstallProcessor> installProcessors) {
		this.installProcessors = installProcessors;
	}

	public String getNodeName() {
		return "database-installer";
	}

	public void setConfiguration(XmlNode xmlNode) {
		this.config = xmlNode;
		XmlNode node = config.getSubNode("database");
		dbLanguage = node.getAttribute("type");
		if(dbLanguage==null||"".equals(dbLanguage))
			dbLanguage = defaultLanuage;
		logger.logMessage(LogLevel.INFO, "当前数据库语言为:{dbLanguage}",dbLanguage);
	}

	public XmlNode getConfiguration() {
		return this.config;
	}
	
	public String getLanguage(){
		if("".equals(dbLanguage))
			return defaultLanuage;
		return dbLanguage;
	}

	public void process() {
		logger.logMessage(LogLevel.INFO, "开始进行{0}数据库安装处理",dbLanguage);
		Collections.sort(installProcessors, new Comparator<InstallProcessor>() {
			public int compare(InstallProcessor o1, InstallProcessor o2) {
				if(o1!=null&&o2!=null){
					return o1.getOrder()>o2.getOrder()?1:(o1.getOrder()==o2.getOrder()?0:-1);
				}
				return 0;
			}
		});
		for (InstallProcessor installProcessor : installProcessors) {
			if(installProcessor!=null){
				 installProcessor.process(dbLanguage);
			}
		}
		logger.logMessage(LogLevel.INFO, "{0}数据库安装处理结束",dbLanguage);
	}


}
