package org.tinygroup.databasebuinstaller.impl;

import java.sql.Connection;
import java.sql.DatabaseMetaData;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.List;

import org.tinygroup.database.config.table.Table;
import org.tinygroup.database.table.TableProcessor;
import org.tinygroup.logger.LogLevel;

/**
 * 
 * 功能说明:数据库表新建、字段更新、删除操作 
 * <p> 系统版本: v1.0<br>
 * 开发人员: renhui <br>
 * 开发时间: 2013-8-15 <br>
 * 功能描述: 写明作用，调用方式，使用场景，以及特殊情况<br>
 */
public class TableInstallProcessor extends AbstractInstallProcessor {

	
	private List<Table> tableList = new ArrayList<Table>();
	private TableProcessor tableProcessor;

	public TableProcessor getTableProcessor() {
		return tableProcessor;
	}

	public void setTableProcessor(TableProcessor tableProcessor) {
		this.tableProcessor = tableProcessor;
	}
	
	
	private void deal(String language,Table table, List<String> sqls, Connection connect)throws SQLException  {
		if (tableList.contains(table))
			return;
		tableList.add(table);
		installTable(language,table, sqls, connect);
	}

	private void installTable(String language,Table table, List<String> sqls, Connection connect)throws SQLException  {
		logger.logMessage(LogLevel.INFO, "开始生成表格语句,表格 包:{0},名:{1}",
				table.getPackageName(), table.getName());
		try {
			DatabaseMetaData data = connect.getMetaData();
			// TableSqlProcessor sqlprocessor = new OracleSqlProcessorImpl();
			List<String> tableSqls = null;
			if (tableProcessor.checkTableExist(table, connect.getCatalog(),
					data, language)) {
				tableSqls = tableProcessor.getUpdateSql(table,
						table.getPackageName(), data, connect.getCatalog(),
						language);
			} else {
				tableSqls = tableProcessor.getCreateSql(table,
						table.getPackageName(), language);
			}
			if (tableSqls.size() != 0) {
				logger.logMessage(LogLevel.INFO, "生成sql:{0}", tableSqls);
			} else {
				logger.logMessage(LogLevel.INFO, "无需生成Sql");
			}
			sqls.addAll(tableSqls);
			logger.logMessage(LogLevel.INFO, "生成表格语句完成,表格 包:{0},名:{1}",
					table.getPackageName(), table.getName());
		} catch (Exception e) {
			logger.errorMessage("获取表格sql时出错,表格 包:{0},名:{1}", e,
					table.getPackageName(), table.getName());
			throw new SQLException(e);
		}

	}

	public int getOrder() {
		return HIGHEST_PRECEDENCE;
	}

	@Override
	protected List<String> getDealSqls(Connection con) throws SQLException {
		logger.logMessage(LogLevel.INFO, "开始获取数据库表安装操作执行语句");
		List<Table> list = tableProcessor.getTables();
		List<String> sqls = new ArrayList<String>();
		for (Table table : list) {
			deal(language,table, sqls, con);
		}
		logger.logMessage(LogLevel.INFO, "获取数据库表安装操作执行语句");
		return sqls;
		
	}


}
